@@ -13,6 +13,7 @@
 import collections
 import inspect
 
+from neutron_lib._i18n import _
 from neutron_lib.callbacks import manager
 from neutron_lib.callbacks import priority_group
 
@@ -70,7 +71,9 @@ def receives(resource, events, priority=priority_group.PRIORITY_DEFAULT):
     @has_registry_receivers decorator to setup the __new__ method to
     actually register the instance methods after initialization.
     """
-    assert isinstance(events, (list, tuple, set)), 'events must be collection'
+    if not isinstance(events, (list, tuple, set)):
+        msg = _("'events' must be a collection (list, tuple, set)")
+        raise AssertionError(msg)
 
     def decorator(f):
         for e in events:
@@ -96,6 +99,7 @@ def has_registry_receivers(klass):
             super_new = super(klass, cls).__new__
             if super_new is object.__new__:
                 # object.__new__ doesn't accept args nor kwargs
+                # pylint: disable=no-value-for-parameter
                 instance = super_new(cls)
             else:
                 instance = super_new(cls, *args, **kwargs)
